# Generated by Django 4.2 on 2023-04-29 15:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='domains',
            name='Description',
            field=models.CharField(blank=True, max_length=15),
        ),
    ]



import os

from django import forms
from django.core.exceptions import ValidationError
from django.core.validators import RegexValidator
from django.utils.translation import gettext_lazy as _
from bigsansar.contrib.sites.models import domains, pages
from www.settings import BASE_DIR


class create_domainform(forms.ModelForm):
    domain = forms.CharField(max_length=100, min_length=3, validators=[
        RegexValidator('^[a-z0-9.]+\.[a-z0-9]{1,5}$', message='Please enter your correct domain name')],
                             widget=forms.TextInput(attrs={'autofocus': True, 'class': 'form-control', }))

    class Meta:
        model = domains
        fields = ('domain', 'Description', 'user',)


# Generated by Django 4.0.6 on 2022-08-10 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userinfo',
            options={'verbose_name': 'User Advance Information', 'verbose_name_plural': 'Profile Details'},
        ),
    ]
